From b8ff0c87d1874cde55176d13725205188a862827 Mon Sep 17 00:00:00 2001
From: Daniel Keast <daniel@kea.st>
Date: Wed, 28 Dec 2016 19:40:58 +0000
Subject: [PATCH] Remove audio from list of extra groups

Adding users to the audio group causes issues with fast user switching.

The user logged in to the active virtual terminal automatically has access to
sound devices, the audio group is for allowing access to the device at any
other time. Since only one user can use a sound device at a time, switching
away from a user in this group does not remove access and leaves the newly
logged in user with no audio.

https://wiki.ubuntu.com/Audio/TheAudioGroup

https://wiki.archlinux.org/index.php/Advanced_Linux_Sound_Architecture#User_privileges

https://www.freedesktop.org/wiki/Software/PulseAudio/Documentation/User/PerfectSetup

Closes #849265
---
 AdduserCommon.pm                                  |  2 +-
 adduser.conf                                      |  2 +-
 doc/adduser.conf.5                                |  2 +-
 doc/po4a/po/adduser.pot                           |  2 +-
 doc/po4a/po/da.po                                 |  4 ++--
 doc/po4a/po/de.po                                 |  4 ++--
 doc/po4a/po/es.po                                 |  4 ++--
 doc/po4a/po/fr.po                                 |  4 ++--
 doc/po4a/po/it.po                                 |  4 ++--
 doc/po4a/po/pl.po                                 |  4 ++--
 doc/po4a/po/pt.po                                 |  4 ++--
 doc/po4a/po/pt_BR.po                              |  6 +++---
 doc/po4a/po/ru.po                                 |  4 ++--
 doc/po4a/po/sv.po                                 |  4 ++--
 examples/adduser.local.conf                       | 12 ------------
 examples/adduser.local.conf.examples/adduser.conf |  2 +-
 16 files changed, 26 insertions(+), 38 deletions(-)

diff --git a/AdduserCommon.pm b/AdduserCommon.pm
index e329bba..3d90aae 100644
--- a/AdduserCommon.pm
+++ b/AdduserCommon.pm
@@ -210,7 +210,7 @@ sub preseed_config {
   $configref->{"name_regex"} = "^[a-z][-a-z0-9_]*\$";
   $configref->{"exclude_fstypes"} = "(proc|sysfs|usbfs|devpts|tmpfs)";
   $configref->{"skel_ignore_regex"} = "dpkg-(old|new|dist)\$";
-  $configref->{"extra_groups"} = "dialout cdrom floppy audio video plugdev users";
+  $configref->{"extra_groups"} = "dialout cdrom floppy video plugdev users";
   $configref->{"add_extra_groups"} = 0;
 
   foreach( @$conflistref ) {
diff --git a/adduser.conf b/adduser.conf
index d045994..d167a4b 100644
--- a/adduser.conf
+++ b/adduser.conf
@@ -74,7 +74,7 @@ SKEL_IGNORE_REGEX="dpkg-(old|new|dist|save)"
 # new users to other groups.
 # This is the list of groups that new non-system users will be added to
 # Default:
-#EXTRA_GROUPS="dialout cdrom floppy audio video plugdev users"
+#EXTRA_GROUPS="dialout cdrom floppy video plugdev users"
 
 # If ADD_EXTRA_GROUPS is set to something non-zero, the EXTRA_GROUPS
 # option above will be default behavior for adding new, non-system users
diff --git a/doc/adduser.conf.5 b/doc/adduser.conf.5
index d9bdc5f..c2df58f 100644
--- a/doc/adduser.conf.5
+++ b/doc/adduser.conf.5
@@ -136,7 +136,7 @@ EXTRA_GROUPS (below).
 .TP
 \fBEXTRA_GROUPS\fB
 This is the list of groups that new non-system users will be added to.
-By default, this list is 'dialout cdrom floppy audio video plugdev users games'.
+By default, this list is 'dialout cdrom floppy video plugdev users games'.
 .SH NOTES
 .TP
 \fBVALID NAMES\fB
diff --git a/doc/po4a/po/adduser.pot b/doc/po4a/po/adduser.pot
index 9387feb..3c8a307 100644
--- a/doc/po4a/po/adduser.pot
+++ b/doc/po4a/po/adduser.pot
@@ -979,7 +979,7 @@ msgstr ""
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users "
+"default, this list is 'dialout cdrom floppy video plugdev users "
 "games'."
 msgstr ""
 
diff --git a/doc/po4a/po/da.po b/doc/po4a/po/da.po
index e519de9..b7de0a4 100644
--- a/doc/po4a/po/da.po
+++ b/doc/po4a/po/da.po
@@ -1166,10 +1166,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'."
+"default, this list is 'dialout cdrom floppy video plugdev users games'."
 msgstr ""
 "Dette er listen over grupper som nye brugere, der ikke er systembrugere, vil "
-"blive tilføjet til. Som standard er denne liste »dialout cdrom floppy audio "
+"blive tilføjet til. Som standard er denne liste »dialout cdrom floppy "
 "video plugdev users games«."
 
 #. type: SH
diff --git a/doc/po4a/po/de.po b/doc/po4a/po/de.po
index cf40fc0..1990a33 100644
--- a/doc/po4a/po/de.po
+++ b/doc/po4a/po/de.po
@@ -1210,10 +1210,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'."
+"default, this list is 'dialout cdrom floppy video plugdev users games'."
 msgstr ""
 "Die neu eingerichteten Nicht-System-Benutzer werden diesen Gruppen "
-"zugeordnet. Die Standardgruppen sind »dialout cdrom floppy audio video "
+"zugeordnet. Die Standardgruppen sind »dialout cdrom floppy video "
 "plugdev users games«."
 
 #. type: SH
diff --git a/doc/po4a/po/es.po b/doc/po4a/po/es.po
index d7eb00b..58304fe 100644
--- a/doc/po4a/po/es.po
+++ b/doc/po4a/po/es.po
@@ -1298,10 +1298,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'"
+"default, this list is 'dialout cdrom floppy video plugdev users games'"
 msgstr ""
 "La lista de grupos a la que se añadirán usuarios no del sistema. Por "
-"omisión, esta lista es «dialout cdrom floppy audio video plugdev users "
+"omisión, esta lista es «dialout cdrom floppy video plugdev users "
 "games»."
 
 #. type: SH
diff --git a/doc/po4a/po/fr.po b/doc/po4a/po/fr.po
index 7987091..cd65451 100644
--- a/doc/po4a/po/fr.po
+++ b/doc/po4a/po/fr.po
@@ -1344,10 +1344,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'."
+"default, this list is 'dialout cdrom floppy video plugdev users games'."
 msgstr ""
 "La liste des groupes auxquels seront ajoutés les utilisateurs non-système. "
-"Par défaut, la liste est « dialout cdrom floppy audio video plugdev users "
+"Par défaut, la liste est « dialout cdrom floppy video plugdev users "
 "games »."
 
 # type: SH
diff --git a/doc/po4a/po/it.po b/doc/po4a/po/it.po
index 216d13c..03f6751 100644
--- a/doc/po4a/po/it.po
+++ b/doc/po4a/po/it.po
@@ -1325,10 +1325,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'."
+"default, this list is 'dialout cdrom floppy video plugdev users games'."
 msgstr ""
 "Elenco dei gruppi a cui vengono aggiunti gli utenti normali al momento della "
-"loro creazione. Il valore predefinito è \"dialout cdrom floppy audio video "
+"loro creazione. Il valore predefinito è \"dialout cdrom floppy video "
 "plugdev users games\"."
 
 # type: SH
diff --git a/doc/po4a/po/pl.po b/doc/po4a/po/pl.po
index 0e87d25..c4f54e0 100644
--- a/doc/po4a/po/pl.po
+++ b/doc/po4a/po/pl.po
@@ -1198,10 +1198,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'."
+"default, this list is 'dialout cdrom floppy video plugdev users games'."
 msgstr ""
 "Lista grup, do których będą dodawanie nowo tworzeni użytkownicy "
-"niesystemowi. Domyślną wartością jest \"dialout cdrom floppy audio video "
+"niesystemowi. Domyślną wartością jest \"dialout cdrom floppy video "
 "plugdev users games\"."
 
 #. type: SH
diff --git a/doc/po4a/po/pt.po b/doc/po4a/po/pt.po
index 703f6b8..9b6669f 100644
--- a/doc/po4a/po/pt.po
+++ b/doc/po4a/po/pt.po
@@ -1319,10 +1319,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'."
+"default, this list is 'dialout cdrom floppy video plugdev users games'."
 msgstr ""
 "Isto é a lista de grupos à qual os novos utilizadores não-do-sistema serão "
-"adicionados. Por predefinição, esta lista é 'dialout cdrom floppy audio "
+"adicionados. Por predefinição, esta lista é 'dialout cdrom floppy "
 "video plugdev users games'."
 
 #. type: SH
diff --git a/doc/po4a/po/pt_BR.po b/doc/po4a/po/pt_BR.po
index 10147e9..7e17379 100644
--- a/doc/po4a/po/pt_BR.po
+++ b/doc/po4a/po/pt_BR.po
@@ -1368,13 +1368,13 @@ msgstr "B<EXTRA_GROUPS>"
 #, fuzzy
 #| msgid ""
 #| "This is the list of groups that new non-system users will be added to.  "
-#| "By default, this list is 'dialout cdrom floppy audio src video lp users'"
+#| "By default, this list is 'dialout cdrom floppy src video lp users'"
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'"
+"default, this list is 'dialout cdrom floppy video plugdev users games'"
 msgstr ""
 "Esta é a lista de grupos nos quais novos usuários comuns (\"non-system\") "
-"serão adicionados. Por padrão, esta lista é 'dialout cdrom floppy audio src "
+"serão adicionados. Por padrão, esta lista é 'dialout cdrom floppy src "
 "video lp users'"
 
 #. type: SH
diff --git a/doc/po4a/po/ru.po b/doc/po4a/po/ru.po
index eba5417..2bb67f3 100644
--- a/doc/po4a/po/ru.po
+++ b/doc/po4a/po/ru.po
@@ -1328,10 +1328,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'."
+"default, this list is 'dialout cdrom floppy video plugdev users games'."
 msgstr ""
 "Это список групп, в которые будут добавлены новые не системные пользователи. "
-"По умолчанию, список равен «dialout cdrom floppy audio video plugdev users "
+"По умолчанию, список равен «dialout cdrom floppy video plugdev users "
 "games»."
 
 # type: SH
diff --git a/doc/po4a/po/sv.po b/doc/po4a/po/sv.po
index 15797ba..f795907 100644
--- a/doc/po4a/po/sv.po
+++ b/doc/po4a/po/sv.po
@@ -1280,10 +1280,10 @@ msgstr "B<EXTRA_GROUPS>"
 #: ../adduser.conf.5:140
 msgid ""
 "This is the list of groups that new non-system users will be added to.  By "
-"default, this list is 'dialout cdrom floppy audio video plugdev users games'"
+"default, this list is 'dialout cdrom floppy video plugdev users games'"
 msgstr ""
 "Detta är listan på grupper som nya icke-systemanvändare kommer att läggas "
-"till i.  Som standard är denna lista \"dialout cdrom floppy audio video "
+"till i.  Som standard är denna lista \"dialout cdrom floppy video "
 "plugdev users games\""
 
 #. type: SH
diff --git a/examples/adduser.local.conf b/examples/adduser.local.conf
index e89e468..b1cec21 100644
--- a/examples/adduser.local.conf
+++ b/examples/adduser.local.conf
@@ -179,18 +179,6 @@ group[floppy] = floppy
 addtogroup[floppy] = true
 
 
-#####################
-#   AUDIO service   #
-#####################
-
-# Add the user to the Unix group "audio" (if it exists).  This allows the
-# user to access the audio hardware on the machine.
-
-service = audio
-group[audio] = audio
-addtogroup[audio] = true
-
-
 ###################
 #   DIP service   #
 ###################
diff --git a/examples/adduser.local.conf.examples/adduser.conf b/examples/adduser.local.conf.examples/adduser.conf
index a3b914e..da0231e 100644
--- a/examples/adduser.local.conf.examples/adduser.conf
+++ b/examples/adduser.local.conf.examples/adduser.conf
@@ -79,7 +79,7 @@ SKEL_IGNORE_REGEX="dpkg-(old|new|dist|save)"
 # new users to other groups.
 # This is the list of groups that new non-system users will be added to
 # Default:
-#EXTRA_GROUPS="dialout cdrom floppy audio video plugdev users"
+#EXTRA_GROUPS="dialout cdrom floppy video plugdev users"
 
 # If ADD_EXTRA_GROUPS is set to something non-zero, the EXTRA_GROUPS
 # option above will be default behavior for adding new, non-system users
-- 
2.1.4

